@@ -1,29 +1,15 @@
 /*
- * This file is part of the KDE project
- *
- * Copyright © 2014 Fredrik Höglund <fredrik@kde.org>
- * Copyright © 2014 Marco Martin <mart@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+    This file is part of the KDE project
+
+    SPDX-FileCopyrightText: 2014 Fredrik Höglund <fredrik@kde.org>
+    SPDX-FileCopyrightText: 2014 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef PLASMA_PLOTTER_H
 #define PLASMA_PLOTTER_H
 
-
 #include <epoxy/gl.h>
 
 // qopengl.h declares GLdouble as a typedef of float when Qt is built
@@ -39,13 +25,11 @@
 #define QOPENGLF_APIENTRYP GLAPIENTRYP
 #endif
 
-#include <QSGTexture>
-#include <QSGSimpleTextureNode>
-#include <QQuickItem>
-#include <QQmlListProperty>
-#include <QPointer>
-#include <QQuickWindow>
 #include <QMutex>
+#include <QPointer>
+#include <QQmlListProperty>
+#include <QQuickItem>
+#include <QQuickWindow>
 
 class PlotSGNode;
 
@@ -167,7 +151,6 @@ class Plotter : public QQuickItem
      */
     Q_PROPERTY(QColor gridColor READ gridColor WRITE setGridColor NOTIFY gridColorChanged)
 
-
     /**
      * The number of horizontal lines drawn across the view between 0 and rangeMax at the top of the plotter at rangeMax
      * This does not include the bottom line
@@ -177,7 +160,7 @@ class Plotter : public QQuickItem
      */
     Q_PROPERTY(int horizontalGridLineCount READ horizontalGridLineCount WRITE setHorizontalGridLineCount NOTIFY horizontalGridLineCountChanged)
 
-    //Q_CLASSINFO("DefaultProperty", "dataSets")
+    // Q_CLASSINFO("DefaultProperty", "dataSets")
 
 public:
     Plotter(QQuickItem *parent = nullptr);
@@ -260,7 +243,7 @@ private:
     bool m_haveInternalFormatQuery;
     GLenum m_internalFormat;
     int m_samples;
-    QPointer <QQuickWindow> m_window;
+    QPointer<QQuickWindow> m_window;
     QMutex m_mutex;
 };
 
