@@ -7,9 +7,8 @@
 
 #include "quickviewsharedengine.h"
 
-#include <QUrl>
-#include <QQmlEngine>
 #include <QQmlContext>
+#include <QQmlEngine>
 #include <QQuickItem>
 
 #include <KLocalizedString>
@@ -18,21 +17,19 @@
 #include <KPackage/Package>
 #include <KPackage/PackageLoader>
 
-namespace KQuickAddons {
-
+namespace KQuickAddons
+{
 class QuickViewSharedEnginePrivate
 {
 public:
     QuickViewSharedEnginePrivate(QuickViewSharedEngine *module)
-        : q(module),
-          resizeMode(QuickViewSharedEngine::ResizeMode::SizeRootObjectToView),
-          initialSize(0, 0)
+        : q(module)
+        , resizeMode(QuickViewSharedEngine::ResizeMode::SizeRootObjectToView)
+        , initialSize(0, 0)
     {
         qmlObject = new KDeclarative::QmlObjectSharedEngine(q);
-        QObject::connect(qmlObject, &KDeclarative::QmlObject::statusChanged,
-                         q, &QuickViewSharedEngine::statusChanged);
-        QObject::connect(qmlObject, SIGNAL(finished()),
-                         q, SLOT(executionFinished()));
+        QObject::connect(qmlObject, &KDeclarative::QmlObject::statusChanged, q, &QuickViewSharedEngine::statusChanged);
+        QObject::connect(qmlObject, SIGNAL(finished()), q, SLOT(executionFinished()));
     }
 
     void executionFinished();
@@ -40,12 +37,10 @@ public:
     void syncWidth();
     void syncHeight();
 
-
     QuickViewSharedEngine *q;
     KDeclarative::QmlObjectSharedEngine *qmlObject;
     QuickViewSharedEngine::ResizeMode resizeMode;
     QSize initialSize;
-
 };
 
 void QuickViewSharedEnginePrivate::executionFinished()
@@ -61,9 +56,9 @@ void QuickViewSharedEnginePrivate::executionFinished()
     }
 
     item->setParentItem(q->contentItem());
-    initialSize = QSize(item->width(), item ->height());
+    initialSize = QSize(item->width(), item->height());
 
-    if(q->size().isEmpty()) {
+    if (q->size().isEmpty()) {
         q->resize(initialSize);
         q->contentItem()->setSize(initialSize);
     }
@@ -82,17 +77,12 @@ void QuickViewSharedEnginePrivate::syncResizeMode()
     if (resizeMode == QuickViewSharedEngine::SizeRootObjectToView) {
         item->setSize(QSize(q->width(), q->height()));
 
-        QObject::disconnect(item, SIGNAL(widthChanged()),
-                            q, SLOT(syncWidth()));
-        QObject::disconnect(item, SIGNAL(heightChanged()),
-                            q, SLOT(syncHeight()));
+        QObject::disconnect(item, SIGNAL(widthChanged()), q, SLOT(syncWidth()));
+        QObject::disconnect(item, SIGNAL(heightChanged()), q, SLOT(syncHeight()));
 
     } else {
-
-        QObject::connect(item, SIGNAL(widthChanged()),
-                         q, SLOT(syncWidth()));
-        QObject::connect(item, SIGNAL(heightChanged()),
-                         q, SLOT(syncHeight()));
+        QObject::connect(item, SIGNAL(widthChanged()), q, SLOT(syncWidth()));
+        QObject::connect(item, SIGNAL(heightChanged()), q, SLOT(syncHeight()));
 
         syncWidth();
         syncHeight();
@@ -121,11 +111,9 @@ void QuickViewSharedEnginePrivate::syncHeight()
     q->setHeight(item->height());
 }
 
-
-
 QuickViewSharedEngine::QuickViewSharedEngine(QWindow *parent)
-    : QQuickWindow(parent),
-      d(new QuickViewSharedEnginePrivate(this))
+    : QQuickWindow(parent)
+    , d(new QuickViewSharedEnginePrivate(this))
 {
 }
 
@@ -133,7 +121,6 @@ QuickViewSharedEngine::~QuickViewSharedEngine()
 {
 }
 
-
 void QuickViewSharedEngine::setTranslationDomain(const QString &translationDomain)
 {
     d->qmlObject->setTranslationDomain(translationDomain);
@@ -193,7 +180,7 @@ QQmlContext *QuickViewSharedEngine::rootContext() const
 
 QQuickItem *QuickViewSharedEngine::rootObject() const
 {
-     return qobject_cast<QQuickItem *>(d->qmlObject->rootObject());
+    return qobject_cast<QQuickItem *>(d->qmlObject->rootObject());
 }
 
 void QuickViewSharedEngine::setResizeMode(ResizeMode mode)
@@ -204,7 +191,7 @@ void QuickViewSharedEngine::setResizeMode(ResizeMode mode)
 
     d->resizeMode = mode;
 
-    emit resizeModeChanged(mode);
+    Q_EMIT resizeModeChanged(mode);
 
     QQuickItem *item = qobject_cast<QQuickItem *>(d->qmlObject->rootObject());
     if (!item) {
@@ -221,7 +208,7 @@ void QuickViewSharedEngine::setSource(const QUrl &url)
     }
 
     d->qmlObject->setSource(url);
-    emit sourceChanged(url);
+    Q_EMIT sourceChanged(url);
 }
 
 QUrl QuickViewSharedEngine::source() const
@@ -251,4 +238,3 @@ void QuickViewSharedEngine::resizeEvent(QResizeEvent *e)
 }
 
 #include "moc_quickviewsharedengine.cpp"
-
